#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "RC6","my secret key";
RandomIV"V#|{}
| T¸`l XM-ӂJOQwz01jxD1nLzYgq}:Q;R.J?ֺW+v
ʘ8+M aebrEv3wEH̻mLXvM0